==> core-1.0-sources.jar: one/xingyi/core/httpClient/client/view/UrlPattern.java <==
package one.xingyi.core.httpClient.client.view;
//Made by one.xingyi.core.filemaker.ClientViewInterfaceFileMaker
//Defn one.xingyi.core.httpClient.IUrlPatternDefn
import one.xingyi.core.sdk.IXingYiView;
import one.xingyi.core.annotations.XingYiGenerated;
import java.util.function.Function;
import one.xingyi.core.http.ServiceRequest;
import one.xingyi.core.http.ServiceResponse;
import one.xingyi.core.utils.IdAndValue;
import java.util.Optional;
import one.xingyi.core.optics.Lens;
import java.util.concurrent.CompletableFuture;
import one.xingyi.core.httpClient.HttpServiceCompletableFuture;
import one.xingyi.core.httpClient.client.view.UrlPattern;
import java.lang.String;
public interface UrlPattern  extends IXingYiView<one.xingyi.core.httpClient.client.entitydefn.IResourceDetailsClientEntity>{
    public static <T> CompletableFuture<T> get(HttpServiceCompletableFuture service, String id, Function<one.xingyi.core.httpClient.client.view.UrlPattern, T> fn){return service.get(one.xingyi.core.httpClient.client.viewcompanion.UrlPatternCompanion.companion,id,fn);}
    public static <T> CompletableFuture<Optional<T>> getOptional(HttpServiceCompletableFuture service, String id, Function<one.xingyi.core.httpClient.client.view.UrlPattern, T> fn){return service.getOptional(one.xingyi.core.httpClient.client.viewcompanion.UrlPatternCompanion.companion,id,fn);}
    //ViewFieldDom(typeDom=PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String)), name=urlPattern, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('urlPattern');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String)), name=urlPattern, readOnly=false, lensName=lens_ResourceDetails_urlPattern, lensPath=urlPattern/String, javascript=function lens_ResourceDetails_urlPattern(){return lens('urlPattern');};, templated=true, deprecated=false)]
    default public Lens<UrlPattern,java.lang.String> urlPatternLens(){ return xingYi().stringLens(one.xingyi.core.httpClient.client.viewcompanion.UrlPatternCompanion.companion, "lens_ResourceDetails_urlPattern");}
    default public java.lang.String urlPattern(){ return urlPatternLens().get(this);};
    default public UrlPattern withurlPattern(java.lang.String urlPattern){ return urlPatternLens().set(this,urlPattern);}
}

==> core-1.1-sources.jar: one/xingyi/core/httpClient/client/view/UrlPattern.java <==
package one.xingyi.core.httpClient.client.view;
//Made by one.xingyi.core.filemaker.ClientViewInterfaceFileMaker
//Defn one.xingyi.core.httpClient.IUrlPatternDefn
import one.xingyi.core.sdk.IXingYiView;
import one.xingyi.core.annotations.XingYiGenerated;
import java.util.function.Function;
import one.xingyi.core.http.ServiceRequest;
import one.xingyi.core.http.ServiceResponse;
import one.xingyi.core.utils.IdAndValue;
import java.util.Optional;
import one.xingyi.core.optics.Lens;
import java.util.concurrent.CompletableFuture;
import one.xingyi.core.httpClient.HttpServiceCompletableFuture;
import one.xingyi.core.httpClient.client.view.UrlPattern;
import java.lang.String;
public interface UrlPattern  extends IXingYiView<one.xingyi.core.httpClient.client.entitydefn.IResourceDetailsClientEntity>{
    public static <T> CompletableFuture<T> get(HttpServiceCompletableFuture service, String id, Function<one.xingyi.core.httpClient.client.view.UrlPattern, T> fn){return service.get(one.xingyi.core.httpClient.client.viewcompanion.UrlPatternCompanion.companion,id,fn);}
    public static <T> CompletableFuture<Optional<T>> getOptional(HttpServiceCompletableFuture service, String id, Function<one.xingyi.core.httpClient.client.view.UrlPattern, T> fn){return service.getOptional(one.xingyi.core.httpClient.client.viewcompanion.UrlPatternCompanion.companion,id,fn);}
    //ViewFieldDom(typeDom=StringPrimitiveType(), name=urlPattern, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('urlPattern');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=StringPrimitiveType(), name=urlPattern, readOnly=false, lensName=lens_ResourceDetails_urlPattern, lensPath=urlPattern/String, javascript=function lens_ResourceDetails_urlPattern(){return lens('urlPattern');};, templated=true, deprecated=false)]
    default public Lens<UrlPattern,java.lang.String> urlPatternLens(){ return xingYi().stringLens(one.xingyi.core.httpClient.client.viewcompanion.UrlPatternCompanion.companion, "lens_ResourceDetails_urlPattern");}
    default public java.lang.String urlPattern(){ return urlPatternLens().get(this);};
    default public UrlPattern withurlPattern(java.lang.String urlPattern){ return urlPatternLens().set(this,urlPattern);}
}
